@@ -1,10 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import absolute_import
-
-import logging
-
-logger = logging.getLogger(__name__)
-
 import pkg_resources
 VERSION = pkg_resources.get_distribution('django-tastypie-elasticsearch').version
 
@@ -14,4 +8,5 @@ __contact__ = "llonchj@gmail.com"
 __homepage__ = "http://github.com/llonchj/django-tastypie-elasticsearch"
 __docformat__ = "restructuredtext"
 
-from .resources import ElasticSearch
+from elasticsearch.connection import *
+from .resources import ElasticsearchResource
